pub enum NodeRef {
Static(NodeId),
Dynamic(u32),
}Expand description
An ID of a node in either a static or dynamic page.
Variants
Static(NodeId)
A reference to a node in a static page.
Dynamic(u32)
A reference to a node in a dynamic (headless) page.