AnthropicCompatibleChatModelBuilder

Struct AnthropicCompatibleChatModelBuilder 

pub struct AnthropicCompatibleChatModelBuilder<const WITH_NAME: bool> { /* private fields */ }
A builder for an Anthropic compatible chat model.

Implementations

Source

impl AnthropicCompatibleChatModelBuilder<false>

pub fn new() -> AnthropicCompatibleChatModelBuilder<false>

Creates a new builder

Source

impl<const WITH_NAME: bool> AnthropicCompatibleChatModelBuilder<WITH_NAME>

pub fn with_model( self, model: impl ToString, ) -> AnthropicCompatibleChatModelBuilder<true>

Set the name of the model to use.

pub fn with_max_tokens( self, max_tokens: u32, ) -> AnthropicCompatibleChatModelBuilder<WITH_NAME>

Set the default max tokens to use when generating text.

pub fn with_claude_3_5_sonnet(self) -> AnthropicCompatibleChatModelBuilder<true>

Set the model to claude-3-5-sonnet-20241022

pub fn with_claude_3_5_haiku(self) -> AnthropicCompatibleChatModelBuilder<true>

Set the model to claude-3-5-haiku-20241022

pub fn with_claude_3_opus(self) -> AnthropicCompatibleChatModelBuilder<true>

Set the model to claude-3-opus-20240229

pub fn with_claude_3_sonnet(self) -> AnthropicCompatibleChatModelBuilder<true>

Set the model to claude-3-sonnet-20240229

pub fn with_claude_3_haiku(self) -> AnthropicCompatibleChatModelBuilder<true>

Set the model to claude-3-haiku-20240307

pub fn with_client( self, client: AnthropicCompatibleClient, ) -> AnthropicCompatibleChatModelBuilder<WITH_NAME>

Set the client used to make requests to the Anthropic API.

Source

impl AnthropicCompatibleChatModelBuilder<true>

pub fn build(self) -> AnthropicCompatibleChatModel

Build the model.